powered by
Simulates paths of prior projected Polya tree distributions centered around a projected normal distribution.
dsimpriorppt(nsim = 5, mm = 4,mu = c(0, 0), sig = 1, ll = 100, aa = 1, delta = 1.1, units = "radians")
An object with class priorppt.circ whose underlying structure is a list containing the following components:
points where the density is evaluated.
simulated density paths of the prior projected Polya tree.
descriptive statistics: mean direction and concentration of each simulated density.
integer indicating the number of simulations.
integer indicating the number of finite levels of the Polya tree.
mean vector of the projected bivariate normal distribution.
standard deviation of the projected bivariate normal distribution. We advise to always use sig = 1.
number of equally spaced points at which the projected distribution will be evaluated.
alpha. Precision parameter of the Polya tree.
controls of the speed at which the variances of the branching probabilities move down in the tree, rho(m)=m^delta.
units of the support: "radians", "degrees" or "hours".
Nieto-Barajas, L.E. & Nunez-Antonio, G. (2019). Projected Polya tree. https://arxiv.org/pdf/1902.06020.pdf
priorppt.plot, priorppt.summary
priorppt.plot
priorppt.summary
z <- dsimpriorppt(mu = c(5,5), nsim = 5, units = "radians") priorppt.plot(z, plot.type = "line") summary(z$stats)
Run the code above in your browser using DataLab